@@ -20,22 +20,22 @@ def median_flow(hydrogram: list) -> tuple:
 def gen_hydrogram(
     hydrogram: list
 ) -> Generator[float, None, float]:
-    m, mt = median_flow(hydrogram)
+    # m, mt = median_flow(hydrogram)
     t = 0
     r = tuple(float(v) for v in hydrogram.pop(0))
     while True:
-        if r[1] <= m and t >= mt:
-            yield m
-        else:
-            if t >= float(hydrogram[0][0]):
-                r = tuple(float(v) for v in hydrogram.pop(0))
+        # if r[1] <= m and t >= mt:
+        #     yield m
+        # else:
+        if t >= float(hydrogram[0][0]):
+            r = tuple(float(v) for v in hydrogram.pop(0))
     
-            if len(hydrogram) == 0:
-                yield r[1]
-                break
+        if len(hydrogram) == 0:
+            yield r[1]
+            break
     
-            yield r[1] + (float(hydrogram[0][1]) - r[1]) / (float(hydrogram[0][0]) - t)
-            t += 1
+        yield r[1] + (float(hydrogram[0][1]) - r[1]) / (float(hydrogram[0][0]) - t)
+        t += 1
 
     return 0
 
